==> haskell-hls-module-name-plugin-2.1.0.0-99-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-module-name-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-module-name-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-module-name-plugin-2.1.0.0-CuJ7CU7yYZiAoB1vDiMYGa
key:                  hls-module-name-plugin-2.1.0.0-CuJ7CU7yYZiAoB1vDiMYGa
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
synopsis:             Module name plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  92d8506bb0600c058d1b17bd852db7b8
exposed:              True
exposed-modules:      Ide.Plugin.ModuleName
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/hls-module-name-plugin-2.1.0.0

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/hls-module-name-plugin-2.1.0.0

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/hls-module-name-plugin-2.1.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-module-name-plugin
hs-libraries:         HShls-module-name-plugin-2.1.0.0-CuJ7CU7yYZiAoB1vDiMYGa
depends:
    aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi base-4.18.2.1 containers-0.6.7
    directory-1.3.8.5 filepath-1.4.300.1
    ghcide-2.1.0.0-BlCpiz4ZHvtIqUTiKV6UyX
    hls-plugin-api-2.1.0.0-IyHsVCiLch7D25xEM5t6Zs
    lsp-2.1.0.0-FDkJ3hOfaOyD0G3xXwdyeX text-2.0.2 transformers-0.6.1.0
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu

haddock-interfaces:
    /usr/share/doc/haskell-hls-module-name-plugin/html/hls-module-name-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-module-name-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-module-name-plugin-2.1.0.0-100-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-module-name-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-module-name-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-module-name-plugin-2.1.0.0-KJKzp2TVYxxHVlfeR7tWiN
key:                  hls-module-name-plugin-2.1.0.0-KJKzp2TVYxxHVlfeR7tWiN
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
synopsis:             Module name plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  2af13a6a9576cbf29f2d26ca545912a6
exposed:              True
exposed-modules:      Ide.Plugin.ModuleName
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/hls-module-name-plugin-2.1.0.0

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/hls-module-name-plugin-2.1.0.0

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/hls-module-name-plugin-2.1.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-module-name-plugin
hs-libraries:         HShls-module-name-plugin-2.1.0.0-KJKzp2TVYxxHVlfeR7tWiN
depends:
    aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi base-4.18.2.1 containers-0.6.7
    directory-1.3.8.5 filepath-1.4.300.1
    ghcide-2.1.0.0-FnivsoqaY804ocwiGSGs4S
    hls-plugin-api-2.1.0.0-DLt74c0m6zn5iIl3F9hXDn
    lsp-2.1.0.0-FDkJ3hOfaOyD0G3xXwdyeX text-2.0.2 transformers-0.6.1.0
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu

haddock-interfaces:
    /usr/share/doc/haskell-hls-module-name-plugin/html/hls-module-name-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-module-name-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
